create_udtf_function

Macro create_udtf_function 

macro_rules! create_udtf_function {
    ($module:expr, $func_name:ident, $name:expr) => { ... };
}
Creates a singleton instance of a table function

  • $module: A struct implementing TableFunctionImpl to create the function from
  • $name: The name to give to the created function
  • $func_name: The name of the function to be called This is used to ensure creating the list of TableFunction only happens once.